# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class DatasourcesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_datasource(self, **kwargs):
        """
        Archive a datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_datasource(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to delete (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_datasource_with_http_info(**kwargs)
        else:
            (data) = self.archive_datasource_with_http_info(**kwargs)
            return data

    def archive_datasource_with_http_info(self, **kwargs):
        """
        Archive a datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_datasource_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to delete (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_datasource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_datasource`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def clean_up(self, **kwargs):
        """
        Archive stale hosted items
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.clean_up(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatasourceCleanUpInputV1 body: Input parameters for the Datasource clean-up process (required)
        :param str id: ID of the datasource to clean up (required)
        :return: DatasourceCleanUpOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceCleanUpOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.clean_up_with_http_info(**kwargs)
        else:
            (data) = self.clean_up_with_http_info(**kwargs)
            return data

    def clean_up_with_http_info(self, **kwargs):
        """
        Archive stale hosted items
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.clean_up_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatasourceCleanUpInputV1 body: Input parameters for the Datasource clean-up process (required)
        :param str id: ID of the datasource to clean up (required)
        :return: DatasourceCleanUpOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceCleanUpOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clean_up" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `clean_up`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `clean_up`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}/cleanup', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceCleanUpOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def clear_datasource_cache(self, **kwargs):
        """
        Clear cache for all items in this datasource and their dependents.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.clear_datasource_cache(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: (required)
        :param bool recompile_formulas: If true, dependent formulas will be marked as needing recompilation in addition to having their caches cleared. This can be significantly more expensive. It is also typically not necessary because Seeq detects events that require recompilation of dependent formulas and performs the necessary recompilation automatically. Consider consulting Seeq Support before using this option.
        :return: DatasourceCacheClearOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceCacheClearOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.clear_datasource_cache_with_http_info(**kwargs)
        else:
            (data) = self.clear_datasource_cache_with_http_info(**kwargs)
            return data

    def clear_datasource_cache_with_http_info(self, **kwargs):
        """
        Clear cache for all items in this datasource and their dependents.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.clear_datasource_cache_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: (required)
        :param bool recompile_formulas: If true, dependent formulas will be marked as needing recompilation in addition to having their caches cleared. This can be significantly more expensive. It is also typically not necessary because Seeq detects events that require recompilation of dependent formulas and performs the necessary recompilation automatically. Consider consulting Seeq Support before using this option.
        :return: DatasourceCacheClearOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceCacheClearOutputV1
        """

        all_params = ['id', 'recompile_formulas']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clear_datasource_cache" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `clear_datasource_cache`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'recompile_formulas' in params:
            query_params.append(('recompileFormulas', params['recompile_formulas']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}/cache', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceCacheClearOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_datasource(self, **kwargs):
        """
        Create a datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_datasource(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatasourceInputV1 body: Datasource information (required)
        :return: DatasourceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_datasource_with_http_info(**kwargs)
        else:
            (data) = self.create_datasource_with_http_info(**kwargs)
            return data

    def create_datasource_with_http_info(self, **kwargs):
        """
        Create a datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_datasource_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatasourceInputV1 body: Datasource information (required)
        :return: DatasourceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_datasource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_datasource`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def disable_connections(self, **kwargs):
        """
        Disable all connections associated with a datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.disable_connections(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource (required)
        :return: ConnectionsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.disable_connections_with_http_info(**kwargs)
        else:
            (data) = self.disable_connections_with_http_info(**kwargs)
            return data

    def disable_connections_with_http_info(self, **kwargs):
        """
        Disable all connections associated with a datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.disable_connections_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource (required)
        :return: ConnectionsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionsOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_connections" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `disable_connections`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}/disable-connections', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ConnectionsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def fully_archive_datasource(self, **kwargs):
        """
        Archive a datasource, its connections, and all items hosted by the datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.fully_archive_datasource(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to archive (required)
        :return: JobAcceptedOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobAcceptedOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.fully_archive_datasource_with_http_info(**kwargs)
        else:
            (data) = self.fully_archive_datasource_with_http_info(**kwargs)
            return data

    def fully_archive_datasource_with_http_info(self, **kwargs):
        """
        Archive a datasource, its connections, and all items hosted by the datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.fully_archive_datasource_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to archive (required)
        :return: JobAcceptedOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobAcceptedOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fully_archive_datasource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `fully_archive_datasource`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}/archive', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'JobAcceptedOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_datasource(self, **kwargs):
        """
        Get a Datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datasource(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to retrieve (required)
        :return: DatasourceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_datasource_with_http_info(**kwargs)
        else:
            (data) = self.get_datasource_with_http_info(**kwargs)
            return data

    def get_datasource_with_http_info(self, **kwargs):
        """
        Get a Datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datasource_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to retrieve (required)
        :return: DatasourceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_datasource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_datasource`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_datasources(self, **kwargs):
        """
        Get a collection of datasources
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datasources(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str datasource_class: The datasource class, the name of the underlying source, 'CSV File' for example, not specifying this parameter will return datasources of any class
        :param str datasource_id: The datasource ID, an identifier that distinguishes a datasource from others of the same datasource class, 'timeseries/salt' for example, not specifying this parameter will return datasources of any ID
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool include_archived: Whether archived datasources should be included
        :param str scoped_to: The scope of the datasource
        :param bool exclude_globally_scoped: Whether globally scoped datasources should be excluded
        :return: DatasourceOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_datasources_with_http_info(**kwargs)
        else:
            (data) = self.get_datasources_with_http_info(**kwargs)
            return data

    def get_datasources_with_http_info(self, **kwargs):
        """
        Get a collection of datasources
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datasources_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str datasource_class: The datasource class, the name of the underlying source, 'CSV File' for example, not specifying this parameter will return datasources of any class
        :param str datasource_id: The datasource ID, an identifier that distinguishes a datasource from others of the same datasource class, 'timeseries/salt' for example, not specifying this parameter will return datasources of any ID
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool include_archived: Whether archived datasources should be included
        :param str scoped_to: The scope of the datasource
        :param bool exclude_globally_scoped: Whether globally scoped datasources should be excluded
        :return: DatasourceOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputListV1
        """

        all_params = ['datasource_class', 'datasource_id', 'offset', 'limit', 'include_archived', 'scoped_to', 'exclude_globally_scoped']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_datasources" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'datasource_class' in params:
            query_params.append(('datasourceClass', params['datasource_class']))
        if 'datasource_id' in params:
            query_params.append(('datasourceId', params['datasource_id']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'include_archived' in params:
            query_params.append(('includeArchived', params['include_archived']))
        if 'scoped_to' in params:
            query_params.append(('scopedTo', params['scoped_to']))
        if 'exclude_globally_scoped' in params:
            query_params.append(('excludeGloballyScoped', params['exclude_globally_scoped']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_items_hosted_by_datasource(self, **kwargs):
        """
        Get a list of the items hosted by this datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_items_hosted_by_datasource(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource (required)
        :param str data_id: The dataId for a specific hosted item
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: ItemPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPreviewListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_items_hosted_by_datasource_with_http_info(**kwargs)
        else:
            (data) = self.get_items_hosted_by_datasource_with_http_info(**kwargs)
            return data

    def get_items_hosted_by_datasource_with_http_info(self, **kwargs):
        """
        Get a list of the items hosted by this datasource
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_items_hosted_by_datasource_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource (required)
        :param str data_id: The dataId for a specific hosted item
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: ItemPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPreviewListV1
        """

        all_params = ['id', 'data_id', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_items_hosted_by_datasource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_items_hosted_by_datasource`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'data_id' in params:
            query_params.append(('dataId', params['data_id']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}/items', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ItemPreviewListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_precached_items(self, **kwargs):
        """
        Get a list of the data IDs in the specified datasource of signals and conditions to pre-cache.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_precached_items(datasource_class=datasource_class_value, datasource_id=datasource_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str datasource_class: (required)
        :param str datasource_id: (required)
        :param int limit:
        :param str previous_page_last_data_id: The data ID of the last item of the previous page, or null to fetch the first page. Only items with data IDs strictly greater than this data ID will be returned.
        :return: PrecachedItemsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PrecachedItemsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_precached_items_with_http_info(**kwargs)
        else:
            (data) = self.get_precached_items_with_http_info(**kwargs)
            return data

    def get_precached_items_with_http_info(self, **kwargs):
        """
        Get a list of the data IDs in the specified datasource of signals and conditions to pre-cache.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_precached_items_with_http_info(datasource_class=datasource_class_value, datasource_id=datasource_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str datasource_class: (required)
        :param str datasource_id: (required)
        :param int limit:
        :param str previous_page_last_data_id: The data ID of the last item of the previous page, or null to fetch the first page. Only items with data IDs strictly greater than this data ID will be returned.
        :return: PrecachedItemsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PrecachedItemsOutputV1
        """

        all_params = ['datasource_class', 'datasource_id', 'limit', 'previous_page_last_data_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_precached_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'datasource_class' is set
        if ('datasource_class' not in params) or (params['datasource_class'] is None):
            raise ValueError("Missing the required parameter `datasource_class` when calling `get_precached_items`")
        # verify the required parameter 'datasource_id' is set
        if ('datasource_id' not in params) or (params['datasource_id'] is None):
            raise ValueError("Missing the required parameter `datasource_id` when calling `get_precached_items`")


        collection_formats = {}

        path_params = {}
        if 'datasource_class' in params:
            path_params['datasourceClass'] = params['datasource_class']
        if 'datasource_id' in params:
            path_params['datasourceId'] = params['datasource_id']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'previous_page_last_data_id' in params:
            query_params.append(('previousPageLastDataId', params['previous_page_last_data_id']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{datasourceClass}/{datasourceId}/precached-items', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'PrecachedItemsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_status(self, **kwargs):
        """
        Get statistics describing the health of remote datasources
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_status(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: DatasourceStatusOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceStatusOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_status_with_http_info(**kwargs)
        else:
            (data) = self.get_status_with_http_info(**kwargs)
            return data

    def get_status_with_http_info(self, **kwargs):
        """
        Get statistics describing the health of remote datasources
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_status_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: DatasourceStatusOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceStatusOutputV1
        """

        all_params = ['offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_status" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/status', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceStatusOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def recount(self, **kwargs):
        """
        Recount item totals for a datasource. Do not run while datasource is indexing
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.recount(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to recount (required)
        :return: DatasourceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.recount_with_http_info(**kwargs)
        else:
            (data) = self.recount_with_http_info(**kwargs)
            return data

    def recount_with_http_info(self, **kwargs):
        """
        Recount item totals for a datasource. Do not run while datasource is indexing
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.recount_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datasource to recount (required)
        :return: DatasourceOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatasourceOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recount" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `recount`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datasources/{id}/recount', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatasourceOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AnnotationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_selection_ids: List[str]
    _background: Optional[bool]
    _backups: List[DocumentBackupOutputV1]
    _ck_enabled: bool
    _content_ids: List[str]
    _created_at: Optional[str]
    _created_by: Optional[ItemPreviewV1]
    _cron_schedule: List[str]
    _date_range_ids: List[str]
    _description: Optional[str]
    _discoverable: Optional[bool]
    _document: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: bool
    _fixed_width: bool
    _id: str
    _interests: List[AnnotationInterestOutputV1]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _margin_bottom: str
    _margin_left: str
    _margin_right: str
    _margin_top: str
    _name: str
    _next_run_time: Optional[str]
    _page_orientation: str
    _page_size: str
    _published_at: Optional[str]
    _replies: List[AnnotationOutputV1]
    _replies_to: Optional[str]
    _reports_on: Optional[str]
    _status_message: Optional[str]
    _timezone: Optional[str]
    _translation_key: Optional[str]
    _type: str
    _updated_at: Optional[str]


    def __init__(
        self,
        asset_selection_ids: Optional[List[str]] = None,
        background: Optional[bool] = False,
        backups: Optional[List[DocumentBackupOutputV1]] = None,
        ck_enabled: Optional[bool] = False,
        content_ids: Optional[List[str]] = None,
        created_at: Optional[str] = None,
        created_by: Optional[ItemPreviewV1] = None,
        cron_schedule: Optional[List[str]] = None,
        date_range_ids: Optional[List[str]] = None,
        description: Optional[str] = None,
        discoverable: Optional[bool] = False,
        document: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = False,
        fixed_width: Optional[bool] = False,
        id: Optional[str] = None,
        interests: Optional[List[AnnotationInterestOutputV1]] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        margin_bottom: Optional[str] = '0.5in',
        margin_left: Optional[str] = '0.5in',
        margin_right: Optional[str] = '0.5in',
        margin_top: Optional[str] = '0.5in',
        name: Optional[str] = None,
        next_run_time: Optional[str] = None,
        page_orientation: Optional[str] = 'Portrait',
        page_size: Optional[str] = 'Letter',
        published_at: Optional[str] = None,
        replies: Optional[List[AnnotationOutputV1]] = None,
        replies_to: Optional[str] = None,
        reports_on: Optional[str] = None,
        status_message: Optional[str] = None,
        timezone: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def asset_selection_ids(self) -> List[str]: ...

    @asset_selection_ids.setter
    def asset_selection_ids(self, asset_selection_ids: List[str]) -> None: ...

    @property
    def background(self) -> Optional[bool]: ...

    @background.setter
    def background(self, background: Optional[bool]) -> None: ...

    @property
    def backups(self) -> List[DocumentBackupOutputV1]: ...

    @backups.setter
    def backups(self, backups: List[DocumentBackupOutputV1]) -> None: ...

    @property
    def ck_enabled(self) -> bool: ...

    @ck_enabled.setter
    def ck_enabled(self, ck_enabled: bool) -> None: ...

    @property
    def content_ids(self) -> List[str]: ...

    @content_ids.setter
    def content_ids(self, content_ids: List[str]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def created_by(self) -> Optional[ItemPreviewV1]: ...

    @created_by.setter
    def created_by(self, created_by: Optional[ItemPreviewV1]) -> None: ...

    @property
    def cron_schedule(self) -> List[str]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: List[str]) -> None: ...

    @property
    def date_range_ids(self) -> List[str]: ...

    @date_range_ids.setter
    def date_range_ids(self, date_range_ids: List[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def discoverable(self) -> Optional[bool]: ...

    @discoverable.setter
    def discoverable(self, discoverable: Optional[bool]) -> None: ...

    @property
    def document(self) -> Optional[str]: ...

    @document.setter
    def document(self, document: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> bool: ...

    @enabled.setter
    def enabled(self, enabled: bool) -> None: ...

    @property
    def fixed_width(self) -> bool: ...

    @fixed_width.setter
    def fixed_width(self, fixed_width: bool) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def interests(self) -> List[AnnotationInterestOutputV1]: ...

    @interests.setter
    def interests(self, interests: List[AnnotationInterestOutputV1]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def margin_bottom(self) -> str: ...

    @margin_bottom.setter
    def margin_bottom(self, margin_bottom: str) -> None: ...

    @property
    def margin_left(self) -> str: ...

    @margin_left.setter
    def margin_left(self, margin_left: str) -> None: ...

    @property
    def margin_right(self) -> str: ...

    @margin_right.setter
    def margin_right(self, margin_right: str) -> None: ...

    @property
    def margin_top(self) -> str: ...

    @margin_top.setter
    def margin_top(self, margin_top: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def next_run_time(self) -> Optional[str]: ...

    @next_run_time.setter
    def next_run_time(self, next_run_time: Optional[str]) -> None: ...

    @property
    def page_orientation(self) -> str: ...

    @page_orientation.setter
    def page_orientation(self, page_orientation: str) -> None: ...

    @property
    def page_size(self) -> str: ...

    @page_size.setter
    def page_size(self, page_size: str) -> None: ...

    @property
    def published_at(self) -> Optional[str]: ...

    @published_at.setter
    def published_at(self, published_at: Optional[str]) -> None: ...

    @property
    def replies(self) -> List[AnnotationOutputV1]: ...

    @replies.setter
    def replies(self, replies: List[AnnotationOutputV1]) -> None: ...

    @property
    def replies_to(self) -> Optional[str]: ...

    @replies_to.setter
    def replies_to(self, replies_to: Optional[str]) -> None: ...

    @property
    def reports_on(self) -> Optional[str]: ...

    @reports_on.setter
    def reports_on(self, reports_on: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class DatasourceSummaryStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _admin_only_accessible: Optional[bool]
    _allow_requests: Optional[bool]
    _average_indexing_duration: Optional[int]
    _cache_enabled: Optional[bool]
    _connections: Optional[List[ConnectionStatusOutputV1]]
    _connections_connected_count: Optional[int]
    _current_index_at: Optional[str]
    _current_indexing_duration: Optional[int]
    _current_indexing_mode: Optional[str]
    _current_indexing_percentage: Optional[int]
    _current_indexing_started_at: Optional[str]
    _datasource_class: str
    _datasource_id: str
    _datasource_labels: Optional[str]
    _id: str
    _indexing_schedule_supported: Optional[bool]
    _local_datasource: Optional[bool]
    _name: str
    _next_scheduled_index_at: Optional[str]
    _placeholder: Optional[bool]
    _previous_index_at: Optional[str]
    _remaining_indexing_duration: Optional[int]
    _sync_progress: Optional[SyncProgressOutputV1]
    _sync_status: Optional[str]
    _total_connections_count: Optional[int]


    def __init__(
        self,
        admin_only_accessible: Optional[bool] = False,
        allow_requests: Optional[bool] = False,
        average_indexing_duration: Optional[int] = None,
        cache_enabled: Optional[bool] = False,
        connections: Optional[List[ConnectionStatusOutputV1]] = None,
        connections_connected_count: Optional[int] = None,
        current_index_at: Optional[str] = None,
        current_indexing_duration: Optional[int] = None,
        current_indexing_mode: Optional[str] = None,
        current_indexing_percentage: Optional[int] = None,
        current_indexing_started_at: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        datasource_labels: Optional[str] = None,
        id: Optional[str] = None,
        indexing_schedule_supported: Optional[bool] = False,
        local_datasource: Optional[bool] = None,
        name: Optional[str] = None,
        next_scheduled_index_at: Optional[str] = None,
        placeholder: Optional[bool] = False,
        previous_index_at: Optional[str] = None,
        remaining_indexing_duration: Optional[int] = None,
        sync_progress: Optional[SyncProgressOutputV1] = None,
        sync_status: Optional[str] = None,
        total_connections_count: Optional[int] = None,
    ) -> None: ...

    @property
    def admin_only_accessible(self) -> Optional[bool]: ...

    @admin_only_accessible.setter
    def admin_only_accessible(self, admin_only_accessible: Optional[bool]) -> None: ...

    @property
    def allow_requests(self) -> Optional[bool]: ...

    @allow_requests.setter
    def allow_requests(self, allow_requests: Optional[bool]) -> None: ...

    @property
    def average_indexing_duration(self) -> Optional[int]: ...

    @average_indexing_duration.setter
    def average_indexing_duration(self, average_indexing_duration: Optional[int]) -> None: ...

    @property
    def cache_enabled(self) -> Optional[bool]: ...

    @cache_enabled.setter
    def cache_enabled(self, cache_enabled: Optional[bool]) -> None: ...

    @property
    def connections(self) -> Optional[List[ConnectionStatusOutputV1]]: ...

    @connections.setter
    def connections(self, connections: Optional[List[ConnectionStatusOutputV1]]) -> None: ...

    @property
    def connections_connected_count(self) -> Optional[int]: ...

    @connections_connected_count.setter
    def connections_connected_count(self, connections_connected_count: Optional[int]) -> None: ...

    @property
    def current_index_at(self) -> Optional[str]: ...

    @current_index_at.setter
    def current_index_at(self, current_index_at: Optional[str]) -> None: ...

    @property
    def current_indexing_duration(self) -> Optional[int]: ...

    @current_indexing_duration.setter
    def current_indexing_duration(self, current_indexing_duration: Optional[int]) -> None: ...

    @property
    def current_indexing_mode(self) -> Optional[str]: ...

    @current_indexing_mode.setter
    def current_indexing_mode(self, current_indexing_mode: Optional[str]) -> None: ...

    @property
    def current_indexing_percentage(self) -> Optional[int]: ...

    @current_indexing_percentage.setter
    def current_indexing_percentage(self, current_indexing_percentage: Optional[int]) -> None: ...

    @property
    def current_indexing_started_at(self) -> Optional[str]: ...

    @current_indexing_started_at.setter
    def current_indexing_started_at(self, current_indexing_started_at: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> str: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: str) -> None: ...

    @property
    def datasource_id(self) -> str: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: str) -> None: ...

    @property
    def datasource_labels(self) -> Optional[str]: ...

    @datasource_labels.setter
    def datasource_labels(self, datasource_labels: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def indexing_schedule_supported(self) -> Optional[bool]: ...

    @indexing_schedule_supported.setter
    def indexing_schedule_supported(self, indexing_schedule_supported: Optional[bool]) -> None: ...

    @property
    def local_datasource(self) -> Optional[bool]: ...

    @local_datasource.setter
    def local_datasource(self, local_datasource: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def next_scheduled_index_at(self) -> Optional[str]: ...

    @next_scheduled_index_at.setter
    def next_scheduled_index_at(self, next_scheduled_index_at: Optional[str]) -> None: ...

    @property
    def placeholder(self) -> Optional[bool]: ...

    @placeholder.setter
    def placeholder(self, placeholder: Optional[bool]) -> None: ...

    @property
    def previous_index_at(self) -> Optional[str]: ...

    @previous_index_at.setter
    def previous_index_at(self, previous_index_at: Optional[str]) -> None: ...

    @property
    def remaining_indexing_duration(self) -> Optional[int]: ...

    @remaining_indexing_duration.setter
    def remaining_indexing_duration(self, remaining_indexing_duration: Optional[int]) -> None: ...

    @property
    def sync_progress(self) -> Optional[SyncProgressOutputV1]: ...

    @sync_progress.setter
    def sync_progress(self, sync_progress: Optional[SyncProgressOutputV1]) -> None: ...

    @property
    def sync_status(self) -> Optional[str]: ...

    @sync_status.setter
    def sync_status(self, sync_status: Optional[str]) -> None: ...

    @property
    def total_connections_count(self) -> Optional[int]: ...

    @total_connections_count.setter
    def total_connections_count(self, total_connections_count: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ChannelOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'id': 'str',
        'last_published_at': 'str',
        'published_count': 'int',
        'subscriptions': 'list[SubscriptionOutputV1]',
        'type': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'id': 'id',
        'last_published_at': 'lastPublishedAt',
        'published_count': 'publishedCount',
        'subscriptions': 'subscriptions',
        'type': 'type'
    }

    def __init__(self, created_at=None, id=None, last_published_at=None, published_count=None, subscriptions=None, type=None):
        """
        ChannelOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._id = None
        self._last_published_at = None
        self._published_count = None
        self._subscriptions = None
        self._type = None

        if created_at is not None:
          self.created_at = created_at
        if id is not None:
          self.id = id
        if last_published_at is not None:
          self.last_published_at = last_published_at
        if published_count is not None:
          self.published_count = published_count
        if subscriptions is not None:
          self.subscriptions = subscriptions
        if type is not None:
          self.type = type

    @property
    def created_at(self):
        """
        Gets the created_at of this ChannelOutputV1.
        The time, as an ISO timestamp, that the channel was created

        :return: The created_at of this ChannelOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ChannelOutputV1.
        The time, as an ISO timestamp, that the channel was created

        :param created_at: The created_at of this ChannelOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def id(self):
        """
        Gets the id of this ChannelOutputV1.
        The URI that uniquely identifies the channel

        :return: The id of this ChannelOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ChannelOutputV1.
        The URI that uniquely identifies the channel

        :param id: The id of this ChannelOutputV1.
        :type: str
        """

        self._id = id

    @property
    def last_published_at(self):
        """
        Gets the last_published_at of this ChannelOutputV1.
        The time, as an ISO timestamp, that the most recent message was published

        :return: The last_published_at of this ChannelOutputV1.
        :rtype: str
        """
        return self._last_published_at

    @last_published_at.setter
    def last_published_at(self, last_published_at):
        """
        Sets the last_published_at of this ChannelOutputV1.
        The time, as an ISO timestamp, that the most recent message was published

        :param last_published_at: The last_published_at of this ChannelOutputV1.
        :type: str
        """

        self._last_published_at = last_published_at

    @property
    def published_count(self):
        """
        Gets the published_count of this ChannelOutputV1.
        The number of messages published on the channel

        :return: The published_count of this ChannelOutputV1.
        :rtype: int
        """
        return self._published_count

    @published_count.setter
    def published_count(self, published_count):
        """
        Sets the published_count of this ChannelOutputV1.
        The number of messages published on the channel

        :param published_count: The published_count of this ChannelOutputV1.
        :type: int
        """

        self._published_count = published_count

    @property
    def subscriptions(self):
        """
        Gets the subscriptions of this ChannelOutputV1.
        The list of subscriptions

        :return: The subscriptions of this ChannelOutputV1.
        :rtype: list[SubscriptionOutputV1]
        """
        return self._subscriptions

    @subscriptions.setter
    def subscriptions(self, subscriptions):
        """
        Sets the subscriptions of this ChannelOutputV1.
        The list of subscriptions

        :param subscriptions: The subscriptions of this ChannelOutputV1.
        :type: list[SubscriptionOutputV1]
        """

        self._subscriptions = subscriptions

    @property
    def type(self):
        """
        Gets the type of this ChannelOutputV1.
        The type of channel this is

        :return: The type of this ChannelOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ChannelOutputV1.
        The type of channel this is

        :param type: The type of this ChannelOutputV1.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ChannelOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemWithSwapPairsV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _item: ItemPreviewWithAssetsV1
    _parameter_match: float
    _swap_pairs: List[SwapInputV1]


    def __init__(
        self,
        item: Optional[ItemPreviewWithAssetsV1] = None,
        parameter_match: Optional[float] = None,
        swap_pairs: Optional[List[SwapInputV1]] = None,
    ) -> None: ...

    @property
    def item(self) -> ItemPreviewWithAssetsV1: ...

    @item.setter
    def item(self, item: ItemPreviewWithAssetsV1) -> None: ...

    @property
    def parameter_match(self) -> float: ...

    @parameter_match.setter
    def parameter_match(self, parameter_match: float) -> None: ...

    @property
    def swap_pairs(self) -> List[SwapInputV1]: ...

    @swap_pairs.setter
    def swap_pairs(self, swap_pairs: List[SwapInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class BoardsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def compare_board_timeframes(self, **kwargs):
        """
        Compare an action board across two time ranges
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.compare_board_timeframes(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardTimeframeComparisonInputV1 body: (required)
        :param str id: The ID of the board (required)
        :return: BoardTimeframeComparisonResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardTimeframeComparisonResultOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.compare_board_timeframes_with_http_info(**kwargs)
        else:
            (data) = self.compare_board_timeframes_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def compare_board_timeframes_with_http_info(self, **kwargs):
        """
        Compare an action board across two time ranges
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.compare_board_timeframes_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardTimeframeComparisonInputV1 body: (required)
        :param str id: The ID of the board (required)
        :return: BoardTimeframeComparisonResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardTimeframeComparisonResultOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method compare_board_timeframes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `compare_board_timeframes`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `compare_board_timeframes`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}/timeframe-comparison', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardTimeframeComparisonResultOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_board(self, **kwargs):
        """
        Create a new board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_board(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardCreateInputV1 body: (required)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_board_with_http_info(**kwargs)
        else:
            (data) = self.create_board_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_board_with_http_info(self, **kwargs):
        """
        Create a new board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_board_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardCreateInputV1 body: (required)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_board" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_board`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_board_filter(self, **kwargs):
        """
        Create a new board filter
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_board_filter(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardFilterCreateInputV1 body: (required)
        :return: BoardFilterOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardFilterOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_board_filter_with_http_info(**kwargs)
        else:
            (data) = self.create_board_filter_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_board_filter_with_http_info(self, **kwargs):
        """
        Create a new board filter
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_board_filter_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardFilterCreateInputV1 body: (required)
        :return: BoardFilterOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardFilterOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_board_filter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_board_filter`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/filters', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardFilterOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_tile(self, **kwargs):
        """
        Create a new tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_tile(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TileCreateInputV1 body: (required)
        :return: TileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_tile_with_http_info(**kwargs)
        else:
            (data) = self.create_tile_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_tile_with_http_info(self, **kwargs):
        """
        Create a new tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_tile_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TileCreateInputV1 body: (required)
        :return: TileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_tile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_tile`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/tiles', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'TileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_board(self, **kwargs):
        """
        Delete a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_board(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board to delete (required)
        :return: DeleteResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResultOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_board_with_http_info(**kwargs)
        else:
            (data) = self.delete_board_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_board_with_http_info(self, **kwargs):
        """
        Delete a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_board_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board to delete (required)
        :return: DeleteResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResultOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_board" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_board`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DeleteResultOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_board_filter(self, **kwargs):
        """
        Delete a board filter
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_board_filter(filter_id=filter_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str filter_id: The ID of the filter to delete (required)
        :return: DeleteResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResultOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_board_filter_with_http_info(**kwargs)
        else:
            (data) = self.delete_board_filter_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_board_filter_with_http_info(self, **kwargs):
        """
        Delete a board filter
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_board_filter_with_http_info(filter_id=filter_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str filter_id: The ID of the filter to delete (required)
        :return: DeleteResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResultOutputV1
        """

        all_params = ['filter_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_board_filter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'filter_id' is set
        if ('filter_id' not in params) or (params['filter_id'] is None):
            raise ValueError("Missing the required parameter `filter_id` when calling `delete_board_filter`")


        collection_formats = {}

        path_params = {}
        if 'filter_id' in params:
            path_params['filterId'] = params['filter_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/filters/{filterId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DeleteResultOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_tile(self, **kwargs):
        """
        Delete a tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_tile(tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str tile_id: The ID of the tile to delete (required)
        :return: DeleteResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResultOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_tile_with_http_info(**kwargs)
        else:
            (data) = self.delete_tile_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_tile_with_http_info(self, **kwargs):
        """
        Delete a tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_tile_with_http_info(tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str tile_id: The ID of the tile to delete (required)
        :return: DeleteResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResultOutputV1
        """

        all_params = ['tile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_tile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tile_id' is set
        if ('tile_id' not in params) or (params['tile_id'] is None):
            raise ValueError("Missing the required parameter `tile_id` when calling `delete_tile`")


        collection_formats = {}

        path_params = {}
        if 'tile_id' in params:
            path_params['tileId'] = params['tile_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/tiles/{tileId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DeleteResultOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def generate_chart_data(self, **kwargs):
        """
        Generate chart data for a chart tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.generate_chart_data(body=body_value, tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param GenerateChartDataInputV1 body: The description of the chart (required)
        :param str tile_id: The ID of the chart tile (required)
        :return: ChartDataResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ChartDataResultOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.generate_chart_data_with_http_info(**kwargs)
        else:
            (data) = self.generate_chart_data_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def generate_chart_data_with_http_info(self, **kwargs):
        """
        Generate chart data for a chart tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.generate_chart_data_with_http_info(body=body_value, tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param GenerateChartDataInputV1 body: The description of the chart (required)
        :param str tile_id: The ID of the chart tile (required)
        :return: ChartDataResultOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ChartDataResultOutputV1
        """

        all_params = ['body', 'tile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_chart_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `generate_chart_data`")
        # verify the required parameter 'tile_id' is set
        if ('tile_id' not in params) or (params['tile_id'] is None):
            raise ValueError("Missing the required parameter `tile_id` when calling `generate_chart_data`")


        collection_formats = {}

        path_params = {}
        if 'tile_id' in params:
            path_params['tileId'] = params['tile_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/tiles/{tileId}/generate-chart-data', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ChartDataResultOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board(self, **kwargs):
        """
        Get a board by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardTileGetInputV1 body:
        :param str id: The ID of the board (required)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_board_with_http_info(**kwargs)
        else:
            (data) = self.get_board_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_with_http_info(self, **kwargs):
        """
        Get a board by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardTileGetInputV1 body:
        :param str id: The ID of the board (required)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_board" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_board`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_column_values(self, **kwargs):
        """
        Get unique values for a column across all tiles on a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_column_values(id=id_value, column_name=column_name_value, timezone=timezone_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board (required)
        :param str column_name: The column name to retrieve values for (required)
        :param str timezone: Timezone to use for timestamp operations (e.g. 'America/New_York') (required)
        :return: ColumnValuesOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ColumnValuesOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_board_column_values_with_http_info(**kwargs)
        else:
            (data) = self.get_board_column_values_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_column_values_with_http_info(self, **kwargs):
        """
        Get unique values for a column across all tiles on a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_column_values_with_http_info(id=id_value, column_name=column_name_value, timezone=timezone_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board (required)
        :param str column_name: The column name to retrieve values for (required)
        :param str timezone: Timezone to use for timestamp operations (e.g. 'America/New_York') (required)
        :return: ColumnValuesOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ColumnValuesOutputV1
        """

        all_params = ['id', 'column_name', 'timezone']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_board_column_values" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_board_column_values`")
        # verify the required parameter 'column_name' is set
        if ('column_name' not in params) or (params['column_name'] is None):
            raise ValueError("Missing the required parameter `column_name` when calling `get_board_column_values`")
        # verify the required parameter 'timezone' is set
        if ('timezone' not in params) or (params['timezone'] is None):
            raise ValueError("Missing the required parameter `timezone` when calling `get_board_column_values`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'column_name' in params:
            query_params.append(('columnName', params['column_name']))
        if 'timezone' in params:
            query_params.append(('timezone', params['timezone']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}/column-values', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ColumnValuesOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_shared_columns(self, **kwargs):
        """
        Get the shared column names across all tiles on a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_shared_columns(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board (required)
        :return: SharedColumnsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SharedColumnsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_board_shared_columns_with_http_info(**kwargs)
        else:
            (data) = self.get_board_shared_columns_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_shared_columns_with_http_info(self, **kwargs):
        """
        Get the shared column names across all tiles on a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_shared_columns_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board (required)
        :return: SharedColumnsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SharedColumnsOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_board_shared_columns" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_board_shared_columns`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}/shared-columns', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'SharedColumnsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_tile_layout(self, **kwargs):
        """
        Get layout information for all tiles on a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_tile_layout(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board (required)
        :return: TileLayoutOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileLayoutOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_board_tile_layout_with_http_info(**kwargs)
        else:
            (data) = self.get_board_tile_layout_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_board_tile_layout_with_http_info(self, **kwargs):
        """
        Get layout information for all tiles on a board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_board_tile_layout_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the board (required)
        :return: TileLayoutOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileLayoutOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_board_tile_layout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_board_tile_layout`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}/tile-layout', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'TileLayoutOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_boards(self, **kwargs):
        """
        Get all boards
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_boards(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_boards_with_http_info(**kwargs)
        else:
            (data) = self.get_boards_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_boards_with_http_info(self, **kwargs):
        """
        Get all boards
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_boards_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_boards" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_tile(self, **kwargs):
        """
        Get a tile by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_tile(tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardTileGetInputV1 body:
        :param str tile_id: The ID of the tile to fetch (required)
        :return: TileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_tile_with_http_info(**kwargs)
        else:
            (data) = self.get_tile_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_tile_with_http_info(self, **kwargs):
        """
        Get a tile by ID
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_tile_with_http_info(tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardTileGetInputV1 body:
        :param str tile_id: The ID of the tile to fetch (required)
        :return: TileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileOutputV1
        """

        all_params = ['body', 'tile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tile_id' is set
        if ('tile_id' not in params) or (params['tile_id'] is None):
            raise ValueError("Missing the required parameter `tile_id` when calling `get_tile`")


        collection_formats = {}

        path_params = {}
        if 'tile_id' in params:
            path_params['tileId'] = params['tile_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/tiles/{tileId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'TileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_board(self, **kwargs):
        """
        Update an existing board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_board(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardUpdateInputV1 body: (required)
        :param str id: The ID of the board to update (required)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_board_with_http_info(**kwargs)
        else:
            (data) = self.update_board_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_board_with_http_info(self, **kwargs):
        """
        Update an existing board
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_board_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardUpdateInputV1 body: (required)
        :param str id: The ID of the board to update (required)
        :return: BoardOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_board" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_board`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_board`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/{id}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_board_filter(self, **kwargs):
        """
        Update an existing board filter
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_board_filter(body=body_value, filter_id=filter_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardFilterUpdateInputV1 body: (required)
        :param str filter_id: The ID of the filter to update (required)
        :return: BoardFilterOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardFilterOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_board_filter_with_http_info(**kwargs)
        else:
            (data) = self.update_board_filter_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_board_filter_with_http_info(self, **kwargs):
        """
        Update an existing board filter
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_board_filter_with_http_info(body=body_value, filter_id=filter_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param BoardFilterUpdateInputV1 body: (required)
        :param str filter_id: The ID of the filter to update (required)
        :return: BoardFilterOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BoardFilterOutputV1
        """

        all_params = ['body', 'filter_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_board_filter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_board_filter`")
        # verify the required parameter 'filter_id' is set
        if ('filter_id' not in params) or (params['filter_id'] is None):
            raise ValueError("Missing the required parameter `filter_id` when calling `update_board_filter`")


        collection_formats = {}

        path_params = {}
        if 'filter_id' in params:
            path_params['filterId'] = params['filter_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/filters/{filterId}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'BoardFilterOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_tile(self, **kwargs):
        """
        Update an existing tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_tile(body=body_value, tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TileUpdateInputV1 body: (required)
        :param str tile_id: The ID of the tile to update (required)
        :return: TileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_tile_with_http_info(**kwargs)
        else:
            (data) = self.update_tile_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_tile_with_http_info(self, **kwargs):
        """
        Update an existing tile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_tile_with_http_info(body=body_value, tile_id=tile_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TileUpdateInputV1 body: (required)
        :param str tile_id: The ID of the tile to update (required)
        :return: TileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TileOutputV1
        """

        all_params = ['body', 'tile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_tile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_tile`")
        # verify the required parameter 'tile_id' is set
        if ('tile_id' not in params) or (params['tile_id'] is None):
            raise ValueError("Missing the required parameter `tile_id` when calling `update_tile`")


        collection_formats = {}

        path_params = {}
        if 'tile_id' in params:
            path_params['tileId'] = params['tile_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/boards/tiles/{tileId}', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'TileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConditionTableInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capsule_properties': 'list[str]',
        'condition_properties': 'list[str]',
        'condition_source': 'ConditionSourceV1',
        'end': 'Value',
        'filter': 'Filter',
        'include_asset_column': 'bool',
        'limit': 'int',
        'start': 'Value'
    }

    attribute_map = {
        'capsule_properties': 'capsuleProperties',
        'condition_properties': 'conditionProperties',
        'condition_source': 'conditionSource',
        'end': 'end',
        'filter': 'filter',
        'include_asset_column': 'includeAssetColumn',
        'limit': 'limit',
        'start': 'start'
    }

    def __init__(self, capsule_properties=None, condition_properties=None, condition_source=None, end=None, filter=None, include_asset_column=True, limit=40, start=None):
        """
        ConditionTableInputV1 - a model defined in Swagger
        """

        self._capsule_properties = None
        self._condition_properties = None
        self._condition_source = None
        self._end = None
        self._filter = None
        self._include_asset_column = None
        self._limit = None
        self._start = None

        if capsule_properties is not None:
          self.capsule_properties = capsule_properties
        if condition_properties is not None:
          self.condition_properties = condition_properties
        if condition_source is not None:
          self.condition_source = condition_source
        if end is not None:
          self.end = end
        if filter is not None:
          self.filter = filter
        if include_asset_column is not None:
          self.include_asset_column = include_asset_column
        if limit is not None:
          self.limit = limit
        if start is not None:
          self.start = start

    @property
    def capsule_properties(self):
        """
        Gets the capsule_properties of this ConditionTableInputV1.
        The list of capsule properties to include in the resulting table

        :return: The capsule_properties of this ConditionTableInputV1.
        :rtype: list[str]
        """
        return self._capsule_properties

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties):
        """
        Sets the capsule_properties of this ConditionTableInputV1.
        The list of capsule properties to include in the resulting table

        :param capsule_properties: The capsule_properties of this ConditionTableInputV1.
        :type: list[str]
        """

        self._capsule_properties = capsule_properties

    @property
    def condition_properties(self):
        """
        Gets the condition_properties of this ConditionTableInputV1.
        The list of condition properties that will be concatenated onto each resulting capsule row

        :return: The condition_properties of this ConditionTableInputV1.
        :rtype: list[str]
        """
        return self._condition_properties

    @condition_properties.setter
    def condition_properties(self, condition_properties):
        """
        Sets the condition_properties of this ConditionTableInputV1.
        The list of condition properties that will be concatenated onto each resulting capsule row

        :param condition_properties: The condition_properties of this ConditionTableInputV1.
        :type: list[str]
        """

        self._condition_properties = condition_properties

    @property
    def condition_source(self):
        """
        Gets the condition_source of this ConditionTableInputV1.

        :return: The condition_source of this ConditionTableInputV1.
        :rtype: ConditionSourceV1
        """
        return self._condition_source

    @condition_source.setter
    def condition_source(self, condition_source):
        """
        Sets the condition_source of this ConditionTableInputV1.

        :param condition_source: The condition_source of this ConditionTableInputV1.
        :type: ConditionSourceV1
        """
        if condition_source is None:
            raise ValueError("Invalid value for `condition_source`, must not be `None`")

        self._condition_source = condition_source

    @property
    def end(self):
        """
        Gets the end of this ConditionTableInputV1.

        :return: The end of this ConditionTableInputV1.
        :rtype: Value
        """
        return self._end

    @end.setter
    def end(self, end):
        """
        Sets the end of this ConditionTableInputV1.

        :param end: The end of this ConditionTableInputV1.
        :type: Value
        """
        if end is None:
            raise ValueError("Invalid value for `end`, must not be `None`")

        self._end = end

    @property
    def filter(self):
        """
        Gets the filter of this ConditionTableInputV1.

        :return: The filter of this ConditionTableInputV1.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this ConditionTableInputV1.

        :param filter: The filter of this ConditionTableInputV1.
        :type: Filter
        """

        self._filter = filter

    @property
    def include_asset_column(self):
        """
        Gets the include_asset_column of this ConditionTableInputV1.
        Include asset column in results when running across assets

        :return: The include_asset_column of this ConditionTableInputV1.
        :rtype: bool
        """
        return self._include_asset_column

    @include_asset_column.setter
    def include_asset_column(self, include_asset_column):
        """
        Sets the include_asset_column of this ConditionTableInputV1.
        Include asset column in results when running across assets

        :param include_asset_column: The include_asset_column of this ConditionTableInputV1.
        :type: bool
        """

        self._include_asset_column = include_asset_column

    @property
    def limit(self):
        """
        Gets the limit of this ConditionTableInputV1.
        Maximum number of rows to return

        :return: The limit of this ConditionTableInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this ConditionTableInputV1.
        Maximum number of rows to return

        :param limit: The limit of this ConditionTableInputV1.
        :type: int
        """
        if limit is None:
            raise ValueError("Invalid value for `limit`, must not be `None`")

        self._limit = limit

    @property
    def start(self):
        """
        Gets the start of this ConditionTableInputV1.

        :return: The start of this ConditionTableInputV1.
        :rtype: Value
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this ConditionTableInputV1.

        :param start: The start of this ConditionTableInputV1.
        :type: Value
        """
        if start is None:
            raise ValueError("Invalid value for `start`, must not be `None`")

        self._start = start

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConditionTableInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class BoardsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def compare_board_timeframes(
        self,
        **kwargs: Any,
    ) -> BoardTimeframeComparisonResultOutputV1: ...

    def compare_board_timeframes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_board(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def create_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_board_filter(
        self,
        **kwargs: Any,
    ) -> BoardFilterOutputV1: ...

    def create_board_filter_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_tile(
        self,
        **kwargs: Any,
    ) -> TileOutputV1: ...

    def create_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_board(
        self,
        **kwargs: Any,
    ) -> DeleteResultOutputV1: ...

    def delete_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_board_filter(
        self,
        **kwargs: Any,
    ) -> DeleteResultOutputV1: ...

    def delete_board_filter_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_tile(
        self,
        **kwargs: Any,
    ) -> DeleteResultOutputV1: ...

    def delete_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def generate_chart_data(
        self,
        **kwargs: Any,
    ) -> ChartDataResultOutputV1: ...

    def generate_chart_data_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def get_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board_column_values(
        self,
        **kwargs: Any,
    ) -> ColumnValuesOutputV1: ...

    def get_board_column_values_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board_shared_columns(
        self,
        **kwargs: Any,
    ) -> SharedColumnsOutputV1: ...

    def get_board_shared_columns_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_board_tile_layout(
        self,
        **kwargs: Any,
    ) -> TileLayoutOutputV1: ...

    def get_board_tile_layout_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_boards(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def get_boards_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_tile(
        self,
        **kwargs: Any,
    ) -> TileOutputV1: ...

    def get_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_board(
        self,
        **kwargs: Any,
    ) -> BoardOutputV1: ...

    def update_board_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_board_filter(
        self,
        **kwargs: Any,
    ) -> BoardFilterOutputV1: ...

    def update_board_filter_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_tile(
        self,
        **kwargs: Any,
    ) -> TileOutputV1: ...

    def update_tile_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
